OC.L10N.register(
    "oauth2",
    {
    "OAuth 2.0" : "OAuth 2.0",
    "OAuth 2.0 clients" : "OAuth 2.0-en bezeroak",
    "Name" : "Izena",
    "Redirection URI" : "Birbideraketaren URI",
    "Client Identifier" : "Bezeroaren Identifikadorea",
    "Secret" : "Sekretua",
    "Add client" : "Bezeroa gehitu",
    "Add" : "Gehitu"
},
"nplurals=2; plural=(n != 1);");
